==> quanyi-center-api-0.0.91-insurance-20240312.095502-103-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/insurance/equity/RemoteInsuranceEquityService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.insurance.equity;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.insurance.activity.InsuranceTakeBaseResultDto;
import cn.com.duiba.quanyi.center.api.dto.insurance.equity.InsuranceEquityDto;
import cn.com.duiba.quanyi.center.api.dto.insurance.equity.InsuranceEquitySaveOrUpdateDto;
import cn.com.duiba.quanyi.center.api.param.insurance.InsuranceEquitySearchParam;
import java.util.List;

/**
 * 保司权益表
 * @author kjj mybatis generator 
 * @date 2024-03-04
 */
@AdvancedFeignClient
public interface RemoteInsuranceEquityService {

    /**
     * 税率
     * @return 税率
     */
    String taxRate();

    /**
     * 权益二批次发放时间为创建时间的多少分钟后
     * @return 分钟
     */
    int grantMinutes();
     
    /**
     * 根据条件查询，分页，管理后端列表查询专用
     * @param param 查询条件
     * @return 保司权益集合
     */
    List<InsuranceEquityDto> selectPage(InsuranceEquitySearchParam param);

    /**
     * 根据条件,查询记录的总记录数
     * @param param 查询条件
     * @return 符合条件的记录数
     */
    long selectCount(InsuranceEquitySearchParam param);

    /**
     * 根据主键查询
     * @param id 主键
     * @return 保司权益
     */
    InsuranceEquityDto selectById(Long id);

    /**
     * 新增权益
     * @param dto 新增参数
     * @return 主键
     */
    InsuranceTakeBaseResultDto<Long> save(InsuranceEquitySaveOrUpdateDto dto);

    /**
     * 更新权益
     * @param dto 更新参数
     * @return 主键
     */
    InsuranceTakeBaseResultDto<Long> update(InsuranceEquitySaveOrUpdateDto dto);

    /**
     * 删除权益
     * @param id 主键
     * @param operatorPhone 操作人手机号
     * @return 是否成功
     */
    InsuranceTakeBaseResultDto<Boolean> delete(Long id, String operatorPhone);
}

==> quanyi-center-api-0.0.92-insurance-20240318.032449-10-sources.jar: cn/com/duiba/quanyi/center/api/remoteservice/insurance/equity/RemoteInsuranceEquityService.java <==
package cn.com.duiba.quanyi.center.api.remoteservice.insurance.equity;

import cn.com.duiba.boot.netflix.feign.AdvancedFeignClient;
import cn.com.duiba.quanyi.center.api.dto.insurance.activity.InsuranceTakeBaseResultDto;
import cn.com.duiba.quanyi.center.api.dto.insurance.equity.InsuranceEquityDto;
import cn.com.duiba.quanyi.center.api.dto.insurance.equity.InsuranceEquitySaveOrUpdateDto;
import cn.com.duiba.quanyi.center.api.param.insurance.InsuranceEquitySearchParam;
import java.util.List;

/**
 * 保司权益表
 * @author kjj mybatis generator 
 * @date 2024-03-04
 */
@AdvancedFeignClient
public interface RemoteInsuranceEquityService {

    /**
     * 税率
     * @return 税率
     */
    String taxRate();

    /**
     * 权益二批次发放时间为创建时间的多少分钟后
     * @return 分钟
     */
    int grantMinutes();
     
    /**
     * 根据条件查询，分页，管理后端列表查询专用
     * @param param 查询条件
     * @return 保司权益集合
     */
    List<InsuranceEquityDto> selectPage(InsuranceEquitySearchParam param);

    /**
     * 根据条件,查询记录的总记录数
     * @param param 查询条件
     * @return 符合条件的记录数
     */
    long selectCount(InsuranceEquitySearchParam param);

    /**
     * 根据主键查询
     * @param id 主键
     * @return 保司权益
     */
    InsuranceEquityDto selectById(Long id);

    /**
     * 新增权益
     * @param dto 新增参数
     * @return 主键
     */
    InsuranceTakeBaseResultDto<Long> save(InsuranceEquitySaveOrUpdateDto dto);

    /**
     * 更新权益
     * @param dto 更新参数
     * @return 主键
     */
    InsuranceTakeBaseResultDto<Long> update(InsuranceEquitySaveOrUpdateDto dto);

    /**
     * 删除权益
     * @param id 主键
     * @param operatorPhone 操作人手机号
     * @return 是否成功
     */
    InsuranceTakeBaseResultDto<Boolean> delete(Long id, String operatorPhone);

    /**
     * 根据手机号查询权益
     * @param accountPhone 手机号
     * @return
     */
    List<InsuranceEquityDto> selectByAccountPhone(String accountPhone);


    /**
     * 更新审核状态
     * @param id
     * @param auditStatus
     * @return
     */
    int updateAuditStatus(Long id, int auditStatus);



    /**
     * 更新审核验真状态
     * @param id
     * @param verifyStatus
     * @return
     */
    int updateVerifyStatus(Long id, int verifyStatus);
}
